@@ -418,7 +418,7 @@ typedef enum {
 /**
  * FWUPD_DEVICE_FLAG_UPDATABLE_HIDDEN:
  *
- * The device is updatable but is currently inhbitied from updates in the client.
+ * The device is updatable but is currently inhibited from updates in the client.
  * Reasons include but are not limited to low power or requiring reboot from a previous update.
  *
  * Since: 1.4.1
@@ -607,6 +607,14 @@ typedef guint64 FwupdDeviceFlags;
  * Since 1.8.3
  */
 #define FWUPD_DEVICE_PROBLEM_IS_EMULATED (1u << 6)
+/**
+ * FWUPD_DEVICE_PROBLEM_MISSING_LICENSE:
+ *
+ * The device cannot be updated due to missing vendor's license.
+ *
+ * Since 1.8.6
+ */
+#define FWUPD_DEVICE_PROBLEM_MISSING_LICENSE (1u << 7)
 /**
  * FWUPD_DEVICE_PROBLEM_UNKNOWN:
  *
@@ -863,6 +871,22 @@ typedef enum {
  * Since: 1.8.5
  */
 #define FWUPD_PLUGIN_FLAG_SECURE_CONFIG (1u << 13)
+/**
+ * FWUPD_PLUGIN_FLAG_MODULAR:
+ *
+ * The plugin is loaded from an external module.
+ *
+ * Since: 1.8.6
+ */
+#define FWUPD_PLUGIN_FLAG_MODULAR (1u << 14)
+/**
+ * FWUPD_PLUGIN_FLAG_MEASURE_SYSTEM_INTEGRITY:
+ *
+ * The plugin will be checked that it preserves system state such as `KEK`, `PK`, `BOOT####` etc.
+ *
+ * Since: 1.8.7
+ */
+#define FWUPD_PLUGIN_FLAG_MEASURE_SYSTEM_INTEGRITY (1u << 15)
 /**
  * FWUPD_PLUGIN_FLAG_UNKNOWN:
  *
